package com.ruoyi.powerdistribution.service;

import java.util.List;
import com.ruoyi.powerdistribution.domain.PdmExamineCounty;

/**
 * 四级单位（县公司）考核金额单位：元
Service接口
 * 
 * @author ruoyi
 * @date 2025-01-02
 */
public interface IPdmExamineCountyService 
{
    /**
     * 查询四级单位（县公司）考核金额单位：元

     * 
     * @param id 四级单位（县公司）考核金额单位：元
主键
     * @return 四级单位（县公司）考核金额单位：元

     */
    public PdmExamineCounty selectPdmExamineCountyById(Long id);

    /**
     * 查询四级单位（县公司）考核金额单位：元
列表
     * 
     * @param pdmExamineCounty 四级单位（县公司）考核金额单位：元

     * @return 四级单位（县公司）考核金额单位：元
集合
     */
    public List<PdmExamineCounty> selectPdmExamineCountyList(PdmExamineCounty pdmExamineCounty);

    /**
     * 新增四级单位（县公司）考核金额单位：元

     * 
     * @param pdmExamineCounty 四级单位（县公司）考核金额单位：元

     * @return 结果
     */
    public int insertPdmExamineCounty(PdmExamineCounty pdmExamineCounty);

    /**
     * 修改四级单位（县公司）考核金额单位：元

     * 
     * @param pdmExamineCounty 四级单位（县公司）考核金额单位：元

     * @return 结果
     */
    public int updatePdmExamineCounty(PdmExamineCounty pdmExamineCounty);

    /**
     * 批量删除四级单位（县公司）考核金额单位：元

     * 
     * @param ids 需要删除的四级单位（县公司）考核金额单位：元
主键集合
     * @return 结果
     */
    public int deletePdmExamineCountyByIds(Long[] ids);

    /**
     * 删除四级单位（县公司）考核金额单位：元
信息
     * 
     * @param id 四级单位（县公司）考核金额单位：元
主键
     * @return 结果
     */
    public int deletePdmExamineCountyById(Long id);
}
